@@ -2,24 +2,21 @@ import pdb
 import requests
 
 from typing import Union
-from stoobly_agent.app.models.adapters.header_adapter_factory import HeaderAdapterFactory
 
 from stoobly_agent.app.models.types.request_components import HeaderIndexResponse
 from stoobly_agent.app.settings import Settings
 from stoobly_agent.lib.logger import Logger
 
-class HeaderModel():
+from .factories.resource.header import HeaderResourceFactory
+from .model import Model
+
+class HeaderModel(Model):
 
   def __init__(self, settings: Settings):
-    self.settings = settings
-
-    if not settings.cli.features.remote:
-      self.as_local()
-    else:
-      self.as_remote()
+    super().__init__(settings)
 
   def as_local(self):
-    self.adapter =  HeaderAdapterFactory(self.settings.remote).local_db()
+    self.adapter =  HeaderResourceFactory(self.settings.remote).local_db()
 
   def as_remote(self):
     # raise('Not yet supported.')
