@@ -3,12 +3,10 @@ import pdb
 
 from stoobly_agent import VERSION
 from stoobly_agent.config.constants.env_vars import ENV
+from stoobly_agent.app.settings.constants.mode import TEST
 
-os.environ[ENV] = 'test'
+os.environ[ENV] = TEST
 
 from stoobly_agent.lib.orm.migrate_service import migrate
 
-migrate(VERSION)
-
-def value_not_match_error(v1, v2):
-  return f"Got {v1}, expected {v2}"
\ No newline at end of file
+migrate(VERSION)
\ No newline at end of file
